Authors
=======


The initial core developers of bfieldtools were (in no particular order)

- Joonas Iivanainen
- Antti Mäkinen
- Rasmus Zetter

An up-to-date list of contributors can be seen `on GitHub`_.

.. _on GitHub: https://github.com/bfieldtools/bfieldtools/graphs/contributors
